@@ -58,7 +58,8 @@ class Dataset:
                     "name": name,
                     "description": description,
                 },
-            )
+            ),
+            retry=False,
         )
         res.raise_for_status()
         return cls(cli, res.json())
