@@ -40,7 +40,7 @@ def _request_to_new_client(
         url=cli.base_url + path,
         params=params,
         headers=headers,
-        data=data,
+        data=data or b"",
     )
     res = cli._request(req, retry)
     return old.Client.Response(res)
