@@ -94,7 +94,7 @@ class Cursor:
                 cursor = e.cursor
                 continue
             break
-        logging.info("got %d batches with %d rows in %.2fs", ct, rows, time.perf_counter() - t0)
+        logging.debug("got %d batches with %d rows in %.2fs", ct, rows, time.perf_counter() - t0)
 
     def rows(self) -> Iterator[dict]:
         """
