@@ -39,7 +39,7 @@ class Transaction:
         perform a select on the current transaction, which will include any changes made in the transaction so far.
         """
         self.flush()
-        return self._table._query_cursor(type="select", filter=filter, vars=vars, tx_id=self._id)
+        return self._table._query_cursor(typ="select", filter=filter, vars=vars, tx_id=self._id)
 
     def replace(self, filter: str = "", vars: Union[Dict, List, None] = None, **kwargs) -> Cursor:
         """remove the rows that match the filter from the table and return them in a cursor.
@@ -50,7 +50,7 @@ class Transaction:
         if not filter:
             raise ValueError("For your own safety, a filter is required, use 1==1 to match all rows")
         self.flush()  # we flush any pending changes to be consistent later
-        return self._table._query_cursor(type="replace", filter=filter, vars=vars, tx_id=self._id)
+        return self._table._query_cursor(typ="replace", filter=filter, vars=vars, tx_id=self._id)
 
     def delete(self, query: str = "") -> int:
         """
@@ -82,9 +82,10 @@ class Transaction:
         # recursively split the batch in smaller ones if it's too big
         def write_batch(b: pa.RecordBatch):
             # small enough to be sent in one go
-            if b.nbytes < 30_000_000 and b.num_rows < 5_000:
+            if b.nbytes < self._table.max_insert_size:
                 w.write_batch(b)
             elif b.num_rows > 1:
+                logging.info("splitting batch of %d rows and %d bytes", b.num_rows, b.nbytes)
                 mid = b.num_rows // 2
                 write_batch(b.slice(0, mid))
                 write_batch(b.slice(mid))
@@ -106,6 +107,7 @@ class Transaction:
                 "tx_id": self._id,
             },
             data=buf.getvalue(),
+            retry=False,
         ).json()
         self._buffer = pa.Table.from_pylist([], schema=schema)
 
@@ -135,7 +137,10 @@ class Transaction:
         else:
             raise ValueError(f"unexpected type {type(data)}")
 
-        self._buffer = pa.concat_tables([self._buffer, data]).combine_chunks()
+        if self._buffer.num_rows == 0:
+            self._buffer = data
+        else:
+            self._buffer = pa.concat_tables([self._buffer, data]).combine_chunks()
 
         if self._buffer.num_rows >= 10_000 or self._buffer.nbytes >= 10_000_000:
             self.flush()
